Files

67 lines
36 KiB
HTML
Raw Permalink Normal View History

<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `Texture` struct in crate `sdl2`."><meta name="keywords" content="rust, rustlang, rust-lang, Texture"><title>sdl2::render::Texture - Rust</title><link rel="stylesheet" type="text/css" href="../../normalize.css"><link rel="stylesheet" type="text/css" href="../../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../../dark.css"><link rel="stylesheet" type="text/css" href="../../light.css" id="themeStyle"><script src="../../storage.js"></script><noscript><link rel="stylesheet" href="../../noscript.css"></noscript><link rel="shortcut icon" href="../../favicon.ico"><style type="text/css">#crate-search{background-image:url("../../down-arrow.svg");}</style></head><body class="rustdoc struct"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">&#9776;</div><a href='../../sdl2/index.html'><div class='logo-container'><img src='../../rust-logo.png' alt='logo'></div></a><p class='location'>Struct Texture</p><div class="sidebar-elems"><div class="block items"><a class="sidebar-title" href="#methods">Methods</a><div class="sidebar-links"><a href="#method.alpha_mod">alpha_mod</a><a href="#method.blend_mode">blend_mode</a><a href="#method.color_mod">color_mod</a><a href="#method.from_surface">from_surface</a><a href="#method.gl_bind_texture">gl_bind_texture</a><a href="#method.gl_unbind_texture">gl_unbind_texture</a><a href="#method.gl_with_bind">gl_with_bind</a><a href="#method.query">query</a><a href="#method.raw">raw</a><a href="#method.set_alpha_mod">set_alpha_mod</a><a href="#method.set_blend_mode">set_blend_mode</a><a href="#method.set_color_mod">set_color_mod</a><a href="#method.update">update</a><a href="#method.update_yuv">update_yuv</a><a href="#method.with_lock">with_lock</a></div><a class="sidebar-title" href="#implementations">Trait Implementations</a><div class="sidebar-links"><a href="#impl-Drop">Drop</a></div><a class="sidebar-title" href="#synthetic-implementations">Auto Trait Implementations</a><div class="sidebar-links"><a href="#impl-RefUnwindSafe">RefUnwindSafe</a><a href="#impl-Send">!Send</a><a href="#impl-Sync">!Sync</a><a href="#impl-Unpin">Unpin</a><a href="#impl-UnwindSafe">UnwindSafe</a></div><a class="sidebar-title" href="#blanket-implementations">Blanket Implementations</a><div class="sidebar-links"><a href="#impl-Any">Any</a><a href="#impl-Borrow%3CT%3E">Borrow&lt;T&gt;</a><a href="#impl-BorrowMut%3CT%3E">BorrowMut&lt;T&gt;</a><a href="#impl-From%3CT%3E">From&lt;T&gt;</a><a href="#impl-Into%3CU%3E">Into&lt;U&gt;</a><a href="#impl-TryFrom%3CU%3E">TryFrom&lt;U&gt;</a><a href="#impl-TryInto%3CU%3E">TryInto&lt;U&gt;</a></div></div><p class='location'><a href='../index.html'>sdl2</a>::<wbr><a href='index.html'>render</a></p><script>window.sidebarCurrent = {name: 'Texture', ty: 'struct', relpath: ''};</script><script defer src="sidebar-items.js"></script></div></nav><div class="theme-picker"><button id="theme-picker" aria-label="Pick another theme!"><img src="../../brush.svg" width="18" alt="Pick another theme!"></button><div id="theme-choices"></div></div><script src="../../theme.js"></script><nav class="sub"><form class="search-form"><div class="search-container"><div><select id="crate-search"><option value="All crates">All crates</option></select><input class="search-input" name="search" disabled autocomplete="off" spellcheck="false" placeholder="Click or press S to search, ? for more options…" type="search"></div><a id="settings-menu" href="../../settings.html"><img src="../../wheel.svg" width="18" alt="Change settings"></a></div></form></nav><section id="main" class="content"><h1 class='fqn'><span class='out-of-band'><span id='render-detail'><a id="toggle-all-docs" href="javascript:void(0)" title="collapse all
<p>Every Texture is owned by a <code>TextureCreator</code>. Internally, a texture is destroyed via its <code>Drop</code>
implementation. A texture can only be used by the <code>Canvas</code> it was originally created from, it
is undefined behavior otherwise.</p>
</div><h2 id='methods' class='small-section-header'>Methods<a href='#methods' class='anchor'></a></h2><h3 id='impl' class='impl'><code class='in-band'>impl&lt;'r&gt; <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl' class='anchor'></a><a class='srclink' href='../../src/sdl2/render.rs.html#2039-2216' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.query' class="method"><code id='query.v'>pub fn <a href='#method.query' class='fnname'>query</a>(&amp;self) -&gt; <a class="struct" href="../../sdl2/render/struct.TextureQuery.html" title="struct sdl2::render::TextureQuery">TextureQuery</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2042-2044' title='goto source code'>[src]</a></h4><div class='docblock'><p>Queries the attributes of the texture.</p>
</div><h4 id='method.set_color_mod' class="method"><code id='set_color_mod.v'>pub fn <a href='#method.set_color_mod' class='fnname'>set_color_mod</a>(&amp;mut self, red: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>, green: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>, blue: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>)</code><a class='srclink' href='../../src/sdl2/render.rs.html#2048-2050' title='goto source code'>[src]</a></h4><div class='docblock'><p>Sets an additional color value multiplied into render copy operations.</p>
</div><h4 id='method.color_mod' class="method"><code id='color_mod.v'>pub fn <a href='#method.color_mod' class='fnname'>color_mod</a>(&amp;self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.tuple.html">(</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>, <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>, <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.tuple.html">)</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2054-2056' title='goto source code'>[src]</a></h4><div class='docblock'><p>Gets the additional color value multiplied into render copy operations.</p>
</div><h4 id='method.set_alpha_mod' class="method"><code id='set_alpha_mod.v'>pub fn <a href='#method.set_alpha_mod' class='fnname'>set_alpha_mod</a>(&amp;mut self, alpha: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a>)</code><a class='srclink' href='../../src/sdl2/render.rs.html#2060-2062' title='goto source code'>[src]</a></h4><div class='docblock'><p>Sets an additional alpha value multiplied into render copy operations.</p>
</div><h4 id='method.alpha_mod' class="method"><code id='alpha_mod.v'>pub fn <a href='#method.alpha_mod' class='fnname'>alpha_mod</a>(&amp;self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2066-2068' title='goto source code'>[src]</a></h4><div class='docblock'><p>Gets the additional alpha value multiplied into render copy operations.</p>
</div><h4 id='method.set_blend_mode' class="method"><code id='set_blend_mode.v'>pub fn <a href='#method.set_blend_mode' class='fnname'>set_blend_mode</a>(&amp;mut self, blend: <a class="enum" href="../../sdl2/render/enum.BlendMode.html" title="enum sdl2::render::BlendMode">BlendMode</a>)</code><a class='srclink' href='../../src/sdl2/render.rs.html#2072-2074' title='goto source code'>[src]</a></h4><div class='docblock'><p>Sets the blend mode used for drawing operations (Fill and Line).</p>
</div><h4 id='method.blend_mode' class="method"><code id='blend_mode.v'>pub fn <a href='#method.blend_mode' class='fnname'>blend_mode</a>(&amp;self) -&gt; <a class="enum" href="../../sdl2/render/enum.BlendMode.html" title="enum sdl2::render::BlendMode">BlendMode</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2078-2080' title='goto source code'>[src]</a></h4><div class='docblock'><p>Gets the blend mode used for texture copy operations.</p>
</div><h4 id='method.update' class="method"><code id='update.v'>pub fn <a href='#method.update' class='fnname'>update</a>&lt;R&gt;(<br>&nbsp;&nbsp;&nbsp;&nbsp;&amp;mut self, <br>&nbsp;&nbsp;&nbsp;&nbsp;rect: R, <br>&nbsp;&nbsp;&nbsp;&nbsp;pixel_data: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">&amp;[</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">]</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;pitch: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a><br>) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.unit.html">()</a>, <a class="enum" href="../../sdl2/render/enum.UpdateTextureError.html" title="enum sdl2::render::UpdateTextureError">UpdateTextureError</a>&gt; <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;R: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;<a class="enum" href="https://doc.rust-lang.org/nightly/core/option/enum.Option.html" title="enum core::option::Option">Option</a>&lt;<a class="struct" href="../../sdl2/rect/struct.Rect.html" title="struct sdl2::rect::Rect">Rect</a>&gt;&gt;,&nbsp;</span></code><a class='srclink' href='../../src/sdl2/render.rs.html#2089-2096' title='goto source code'>[src]</a></h4><div class='docblock'><p>Updates the given texture rectangle with new pixel data.</p>
<p><code>pitch</code> is the number of bytes in a row of pixel data, including padding
between lines</p>
<ul>
<li>If <code>rect</code> is <code>None</code>, the entire texture is updated.</li>
</ul>
</div><h4 id='method.update_yuv' class="method"><code id='update_yuv.v'>pub fn <a href='#method.update_yuv' class='fnname'>update_yuv</a>&lt;R&gt;(<br>&nbsp;&nbsp;&nbsp;&nbsp;&amp;mut self, <br>&nbsp;&nbsp;&nbsp;&nbsp;rect: R, <br>&nbsp;&nbsp;&nbsp;&nbsp;y_plane: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">&amp;[</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">]</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;y_pitch: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;u_plane: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">&amp;[</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">]</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;u_pitch: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;v_plane: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">&amp;[</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">]</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;v_pitch: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a><br>) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.unit.html">()</a>, <a class="enum" href="../../sdl2/render/enum.UpdateTextureYUVError.html" title="enum sdl2::render::UpdateTextureYUVError">UpdateTextureYUVError</a>&gt; <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;R: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;<a class="enum" href="https://doc.rust-lang.org/nightly/core/option/enum.Option.html" title="enum core::option::Option">Option</a>&lt;<a class="struct" href="../../sdl2/rect/struct.Rect.html" title="struct sdl2::rect::Rect">Rect</a>&gt;&gt;,&nbsp;</span></code><a class='srclink' href='../../src/sdl2/render.rs.html#2100-2111' title='goto source code'>[src]</a></h4><div class='docblock'><p>Updates a rectangle within a planar YV12 or IYUV texture with new pixel data.</p>
</div><h4 id='method.with_lock' class="method"><code id='with_lock.v'>pub fn <a href='#method.with_lock' class='fnname'>with_lock</a>&lt;F, R, R2&gt;(&amp;mut self, rect: R2, func: F) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;R, <a class="struct" href="https://doc.rust-lang.org/nightly/alloc/string/struct.String.html" title="struct alloc::string::String">String</a>&gt; <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;F: <a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/function/trait.FnOnce.html" title="trait core::ops::function::FnOnce">FnOnce</a>(<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">&amp;mut [</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.u8.html">u8</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">]</a>, <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>) -&gt; R,<br>&nbsp;&nbsp;&nbsp;&nbsp;R2: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;<a class="enum" href="https://doc.rust-lang.org/nightly/core/option/enum.Option.html" title="enum core::option::Option">Option</a>&lt;<a class="struct" href="../../sdl2/rect/struct.Rect.html" title="struct sdl2::rect::Rect">Rect</a>&gt;&gt;,&nbsp;</span></code><a class='srclink' href='../../src/sdl2/render.rs.html#2124-2129' title='goto source code'>[src]</a></h4><div class='docblock'><p>Locks the texture for <strong>write-only</strong> pixel access.
The texture must have been created with streaming access.</p>
<p><code>F</code> is a function that is passed the write-only texture buffer,
and the pitch of the texture (size of a row in bytes).</p>
<h1 id="remarks" class="section-header"><a href="#remarks">Remarks</a></h1>
<p>As an optimization, the pixels made available for editing don't
necessarily contain the old texture data.
This is a write-only operation, and if you need to keep a copy of the
texture data you should do that at the application level.</p>
</div><h4 id='method.gl_bind_texture' class="method"><code id='gl_bind_texture.v'>pub unsafe fn <a href='#method.gl_bind_texture' class='fnname'>gl_bind_texture</a>(&amp;mut self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.tuple.html">(</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.f32.html">f32</a>, <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.f32.html">f32</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.tuple.html">)</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2134-2136' title='goto source code'>[src]</a></h4><div class='docblock'><p>Binds an OpenGL/ES/ES2 texture to the current
context for use with when rendering OpenGL primitives directly.</p>
</div><h4 id='method.gl_unbind_texture' class="method"><code id='gl_unbind_texture.v'>pub unsafe fn <a href='#method.gl_unbind_texture' class='fnname'>gl_unbind_texture</a>(&amp;mut self)</code><a class='srclink' href='../../src/sdl2/render.rs.html#2140-2142' title='goto source code'>[src]</a></h4><div class='docblock'><p>Unbinds an OpenGL/ES/ES2 texture from the current context.</p>
</div><h4 id='method.gl_with_bind' class="method"><code id='gl_with_bind.v'>pub fn <a href='#method.gl_with_bind' class='fnname'>gl_with_bind</a>&lt;R, F:&nbsp;<a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/function/trait.FnOnce.html" title="trait core::ops::function::FnOnce">FnOnce</a>(<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.f32.html">f32</a>, <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.f32.html">f32</a>) -&gt; R&gt;(&amp;mut self, f: F) -&gt; R</code><a class='srclink' href='../../src/sdl2/render.rs.html#2146-2148' title='goto source code'>[src]</a></h4><div class='docblock'><p>Binds and unbinds an OpenGL/ES/ES2 texture from the current context.</p>
</div><h4 id='method.raw' class="method"><code id='raw.v'>pub const fn <a href='#method.raw' class='fnname'>raw</a>(&amp;self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.pointer.html">*mut </a><a class="struct" href="../../sdl2_sys/struct.SDL_Texture.html" title="struct sdl2_sys::SDL_Texture">SDL_Texture</a></code><a class='srclink' href='../../src/sdl2/render.rs.html#2151-2153' title='goto source code'>[src]</a></h4><h4 id='method.from_surface' class="method"><code id='from_surface.v'>pub fn <a href='#method.from_surface' class='fnname'>from_surface</a>&lt;'a, T&gt;(<br>&nbsp;&nbsp;&nbsp;&nbsp;surface: &amp;<a class="struct" href="../../sdl2/surface/struct.Surface.html" title="struct sdl2::surface::Surface">Surface</a>, <br>&nbsp;&nbsp;&nbsp;&nbsp;texture_creator: &amp;'a <a class="struct" href="../../sdl2/render/struct.TextureCreator.html" title="struct sdl2::render::TextureCreator">TextureCreator</a>&lt;T&gt;<br>) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;<a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'a&gt;, <a class="enum" href="../../sdl2/render/enum.TextureValueError.html" title="enum sdl2::render::TextureValueError">TextureValueError</a>&gt;</code><a class='srclink' href='../../src/sdl2/render.rs.html#2182-2184' title='goto source code'>[src]</a></h4><div class='docblock'><p>A convenience function for [<code>TextureCreator::create_texture_from_surface</code>].</p>
<div class="example-wrap"><pre class="rust rust-example-rendered">
<span class="kw">use</span> <span class="ident">sdl2</span>::<span class="ident">pixels</span>::<span class="ident">PixelFormatEnum</span>;
<span class="kw">use</span> <span class="ident">sdl2</span>::<span class="ident">surface</span>::<span class="ident">Surface</span>;
<span class="kw">use</span> <span class="ident">sdl2</span>::<span class="ident">render</span>::{<span class="ident">Canvas</span>, <span class="ident">Texture</span>};
<span class="kw">use</span> <span class="ident">sdl2</span>::<span class="ident">video</span>::<span class="ident">Window</span>;
<span class="comment">// We init systems.</span>
<span class="kw">let</span> <span class="ident">sdl_context</span> <span class="op">=</span> <span class="ident">sdl2</span>::<span class="ident">init</span>().<span class="ident">expect</span>(<span class="string">&quot;failed to init SDL&quot;</span>);
<span class="kw">let</span> <span class="ident">video_subsystem</span> <span class="op">=</span> <span class="ident">sdl_context</span>.<span class="ident">video</span>().<span class="ident">expect</span>(<span class="string">&quot;failed to get video context&quot;</span>);
<span class="comment">// We create a window.</span>
<span class="kw">let</span> <span class="ident">window</span> <span class="op">=</span> <span class="ident">video_subsystem</span>.<span class="ident">window</span>(<span class="string">&quot;sdl2 demo&quot;</span>, <span class="number">800</span>, <span class="number">600</span>)
.<span class="ident">build</span>()
.<span class="ident">expect</span>(<span class="string">&quot;failed to build window&quot;</span>);
<span class="comment">// We get the canvas from which we can get the `TextureCreator`.</span>
<span class="kw">let</span> <span class="kw-2">mut</span> <span class="ident">canvas</span>: <span class="ident">Canvas</span><span class="op">&lt;</span><span class="ident">Window</span><span class="op">&gt;</span> <span class="op">=</span> <span class="ident">window</span>.<span class="ident">into_canvas</span>()
.<span class="ident">build</span>()
.<span class="ident">expect</span>(<span class="string">&quot;failed to build window&#39;s canvas&quot;</span>);
<span class="kw">let</span> <span class="ident">texture_creator</span> <span class="op">=</span> <span class="ident">canvas</span>.<span class="ident">texture_creator</span>();
<span class="kw">let</span> <span class="ident">surface</span> <span class="op">=</span> <span class="ident">Surface</span>::<span class="ident">new</span>(<span class="number">512</span>, <span class="number">512</span>, <span class="ident">PixelFormatEnum</span>::<span class="ident">RGB24</span>).<span class="ident">unwrap</span>();
<span class="kw">let</span> <span class="ident">texture</span> <span class="op">=</span> <span class="ident">Texture</span>::<span class="ident">from_surface</span>(<span class="kw-2">&amp;</span><span class="ident">surface</span>, <span class="kw-2">&amp;</span><span class="ident">texture_creator</span>).<span class="ident">unwrap</span>();</pre></div>
</div></div><h2 id='implementations' class='small-section-header'>Trait Implementations<a href='#implementations' class='anchor'></a></h2><div id='implementations-list'><h3 id='impl-Drop' class='impl'><code class='in-band'>impl&lt;'r&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/drop/trait.Drop.html" title="trait core::ops::drop::Drop">Drop</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-Drop' class='anchor'></a><a class='srclink' href='../../src/sdl2/render.rs.html#1521-1527' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.drop' class="method hidden"><code id='drop.v'>fn <a href='https://doc.rust-lang.org/nightly/core/ops/drop/trait.Drop.html#tymethod.drop' class='fnname'>drop</a>(&amp;mut self)</code><a class='srclink' href='../../src/sdl2/render.rs.html#1522-1526' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Executes the destructor for this type. <a href="https://doc.rust-lang.org/nightly/core/ops/drop/trait.Drop.html#tymethod.drop">Read more</a></p>
</div></div></div><h2 id='synthetic-implementations' class='small-section-header'>Auto Trait Implementations<a href='#synthetic-implementations' class='anchor'></a></h2><div id='synthetic-implementations-list'><h3 id='impl-RefUnwindSafe' class='impl'><code class='in-band'>impl&lt;'r&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/std/panic/trait.RefUnwindSafe.html" title="trait std::panic::RefUnwindSafe">RefUnwindSafe</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-RefUnwindSafe' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Send' class='impl'><code class='in-band'>impl&lt;'r&gt; !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-Send' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Sync' class='impl'><code class='in-band'>impl&lt;'r&gt; !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-Sync' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Unpin' class='impl'><code class='in-band'>impl&lt;'r&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Unpin.html" title="trait core::marker::Unpin">Unpin</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-Unpin' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-UnwindSafe' class='impl'><code class='in-band'>impl&lt;'r&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/std/panic/trait.UnwindSafe.html" title="trait std::panic::UnwindSafe">UnwindSafe</a> for <a class="struct" href="../../sdl2/render/struct.Texture.html" title="struct sdl2::render::Texture">Texture</a>&lt;'r&gt;</code><a href='#impl-UnwindSafe' class='anchor'></a></h3><div class='impl-items'></div></div><h2 id='blanket-implementations' class='small-section-header'>Blanket Implementations<a href='#blanket-implementations' class='anchor'></a></h2><div id='blanket-implementations-list'><h3 id='impl-Any' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html" title="trait core::any::Any">Any</a> for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: 'static + ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-Any' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#108-112' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.type_id' class="method hidden"><code id='type_id.v'>fn <a href='https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id' class='fnname'>type_id</a>(&amp;self) -&gt; <a class="struct" href="https://doc.rust-lang.org/nightly/core/any/struct.TypeId.html" title="struct core::any::TypeId">TypeId</a></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#109-111' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Gets the <code>TypeId</code> of <code>self</code>. <a href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id">Read more</a></p>
</div></div><h3 id='impl-Borrow%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html" title="trait core::borrow::Borrow">Borrow</a>&lt;T&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-Borrow%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#213-217' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow' class="method hidden"><code id='borrow.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow' class='fnname'>borrow</a>(&amp;self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.reference.html">&amp;</a>T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#214-216' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Immutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></p>
</div></div><h3 id='impl-BorrowMut%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html" title="trait core::borrow::BorrowMut">BorrowMut</a>&lt;T&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-BorrowMut%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#220-224' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow_mut' class="method hidden"><code id='borrow_mut.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut' class='fnname'>borrow_mut</a>(&amp;mut self) -&gt; <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.reference.html">&amp;mut </a>T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#221-223' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Mutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></p>
</div></div><h3 id='impl-From%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a>&lt;T&gt; for T</code><a href='#impl-From%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#565-569' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.from' class="method hidden"><code id='from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.From.html#tymethod.from' class='fnname'>from</a>(t: T) -&gt; T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#566-568' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-Into%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-Into%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#554-561' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.into' class="method hidden"><code id='into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.Into.html#tymethod.into' class='fnname'>into</a>(self) -&gt; U</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#558-560' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-TryFrom%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-TryFrom%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#602-611' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error' class="type"><code id='Error.t'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error' class="type">Error</a> = <a class="enum" href="https://doc.rust-lang.org/nightly/core/convert/enum.Infallible.html" title="enum core::convert::Infallible">Infallible</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
</div><h4 id='method.try_from' class="method hidden"><code id='try_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#tymethod.try_from' class='fnname'>try_from</a>(value: U) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;T, &lt;T as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;U&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>&gt;</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#608-610' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-TryInto%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html" title="trait core::convert::TryInto">TryInto</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-TryInto%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#588-597' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error-1' class="type"><code id='Error.t-1'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#associatedtype.Error' class="type">Error</a> = &lt;U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
</div><h4 id='method.try_into' class="method hidden"><code id='try_into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#tymethod.try_into' class='fnname'>try_into</a>(self) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;U, &lt;U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>&gt;</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#594-596' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div></div></section><section id="search" class="content hidden"></section><section class="footer"></section><script>window.rootPath = "../../";window.currentCrate = "sdl2";</script><script src="../../aliases.js"></script><script src="../../main.js"></script><script defer src="../../search-index.js"></script></body></html>